require "selenium-webdriver"
require "selenium/emulated_features"

describe Selenium::EmulatedFeatures::ResponseCode do
  shared_examples "a WebDriver that responds to #response_code" do
    after { driver.quit }

    it "returns the HTTP response code" do
      driver.navigate.to "http://0.0.0.0:9876/status_code/404"
      expect(driver.response_code).to be 404
    end

    it "works for successive requests" do
      driver.navigate.to "http://0.0.0.0:9876/status_code/200"
      expect(driver.response_code).to be 200

      driver.navigate.to "http://0.0.0.0:9876/status_code/418"
      expect(driver.response_code).to be 418
    end
  end

  describe "Firefox driver", firefox: true do
    it_behaves_like "a WebDriver that responds to #response_code" do
      subject(:driver) { Selenium::WebDriver.for(:firefox) }
    end
  end

  describe "Chrome driver", chrome: true do
    it_behaves_like "a WebDriver that responds to #response_code" do
      subject(:driver) { Selenium::WebDriver.for(:chrome) }
    end
  end

  describe "Safari driver", safari: true do
    it_behaves_like "a WebDriver that responds to #response_code" do
      subject(:driver) { Selenium::WebDriver.for(:safari) }
    end
  end

  describe "PhantomJS driver", phantomjs: true do
    it_behaves_like "a WebDriver that responds to #response_code" do
      subject(:driver) { Selenium::WebDriver.for(:phantomjs) }
    end
  end
end
