require "selenium-webdriver"
require "selenium/emulated_features"

describe Selenium::EmulatedFeatures::ResponseHeaders do
  shared_examples "a WebDriver that responds to #response_headers" do
    after { driver.quit }

    it "returns the HTTP response headers" do
      driver.navigate.to "http://0.0.0.0:9876/response_headers"
      expect(driver.response_headers["foo"]).to eq ["Bar"]
      expect(driver.response_headers["alpha"]).to eq ["Beta"]
    end

    it "works for successive requests" do
      driver.navigate.to "http://0.0.0.0:9876/status_code/200"
      headers_a = driver.response_headers

      driver.navigate.to "http://0.0.0.0:9876/response_headers"
      headers_b = driver.response_headers

      expect(headers_a).not_to eq headers_b
    end
  end

  describe "Firefox driver", firefox: true do
    it_behaves_like "a WebDriver that responds to #response_headers" do
      subject(:driver) { Selenium::WebDriver.for(:firefox) }
    end
  end

  describe "Chrome driver", chrome: true do
    it_behaves_like "a WebDriver that responds to #response_headers" do
      subject(:driver) { Selenium::WebDriver.for(:chrome) }
    end
  end

  describe "Safari driver", safari: true do
    it_behaves_like "a WebDriver that responds to #response_headers" do
      subject(:driver) { Selenium::WebDriver.for(:safari) }
    end
  end

  describe "PhantomJS driver", phantomjs: true do
    it_behaves_like "a WebDriver that responds to #response_headers" do
      subject(:driver) { Selenium::WebDriver.for(:phantomjs) }
    end
  end
end
